==> r14.0.8.zip: ksystemlog/ksystemlog/src/system/systemOptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

//TQt includes
#include <tqlayout.h>
#include <tqvgroupbox.h>
#include <tqbuttongroup.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
#include <tqvbox.h>
#include <tqhbox.h>

//KDE includes
#include <tdelocale.h>
#include <tdeactioncollection.h>
#include <kbuttonbox.h>
#include <tdelistbox.h>
#include <tdefiledialog.h>
#include <kurl.h>
#include <tdemessagebox.h>
#include <kiconloader.h>
#include <kdebug.h>

//Project includes
#include "systemOptions.h"
#include "ksystemlogConfig.h"

SystemOptions::SystemOptions(TQWidget *parent) : 
	TQWidget(parent)
	{
	
	TQVBoxLayout* layout = new TQVBoxLayout(this);
	//layout->setAutoAdd(true);

	TQString description= i18n("<qt><p>These files will be analyzed to display <b>System logs</b>. This list also determines the order in which the files are read.</p></qt>");
	fileList=new SpecificFileList(this, description);
	
	connect(fileList, TQT_SIGNAL(fileListChanged(int)), this, TQT_SLOT(slotFileListChanged(int)));

	layout->addWidget(fileList);
	
	readConfig();
	

}

SystemOptions::~SystemOptions() {
	
}

bool SystemOptions::isValid() {
	if (fileList->count()>0)
		return(true);
	else
		return(false);
}

void SystemOptions::slotFileListChanged(int itemLeft) {
	if (itemLeft==0)
		emit optionsChanged(false);
	else
		emit optionsChanged(true);
}

void SystemOptions::saveConfig() {
	kdDebug() << "Saving config from System Options..." << endl;
	
	TQStringList stringList;
	TQValueList<int> valueList;
		
	fileList->saveConfig(stringList, valueList);
	
	KSystemLogConfig::setSystemPaths(stringList);
	KSystemLogConfig::setSystemLevels(valueList);
}

void SystemOptions::readConfig() {
	TQStringList stringList=KSystemLogConfig::systemPaths();
	TQValueList<int> valueList=KSystemLogConfig::systemLevels();
	
	fileList->readConfig(stringList, valueList);
}

#include "systemOptions.moc"

==> r14.1.2.zip: ksystemlog/ksystemlog/src/system/systemOptions.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

//TQt includes
#include <tqlayout.h>
#include <tqvgroupbox.h>
#include <tqbuttongroup.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
#include <tqvbox.h>
#include <tqhbox.h>

//KDE includes
#include <tdelocale.h>
#include <tdeactioncollection.h>
#include <kbuttonbox.h>
#include <tdelistbox.h>
#include <tdefiledialog.h>
#include <kurl.h>
#include <tdemessagebox.h>
#include <kiconloader.h>
#include <kdebug.h>

//Project includes
#include "systemOptions.h"
#include "ksystemlogConfig.h"

SystemOptions::SystemOptions(TQWidget *parent) : 
	TQWidget(parent)
	{
	
	TQVBoxLayout* layout = new TQVBoxLayout(this);
	//layout->setAutoAdd(true);

	TQString description= i18n("<qt><p>These files will be analyzed to display <b>System logs</b>. This list also determines the order in which the files are read.</p></qt>");
	fileList=new SpecificFileList(this, description);
	
	connect(fileList, TQ_SIGNAL(fileListChanged(int)), this, TQ_SLOT(slotFileListChanged(int)));

	layout->addWidget(fileList);
	
	readConfig();
	

}

SystemOptions::~SystemOptions() {
	
}

bool SystemOptions::isValid() {
	if (fileList->count()>0)
		return(true);
	else
		return(false);
}

void SystemOptions::slotFileListChanged(int itemLeft) {
	if (itemLeft==0)
		emit optionsChanged(false);
	else
		emit optionsChanged(true);
}

void SystemOptions::saveConfig() {
	kdDebug() << "Saving config from System Options..." << endl;
	
	TQStringList stringList;
	TQValueList<int> valueList;
		
	fileList->saveConfig(stringList, valueList);
	
	KSystemLogConfig::setSystemPaths(stringList);
	KSystemLogConfig::setSystemLevels(valueList);
}

void SystemOptions::readConfig() {
	TQStringList stringList=KSystemLogConfig::systemPaths();
	TQValueList<int> valueList=KSystemLogConfig::systemLevels();
	
	fileList->readConfig(stringList, valueList);
}

#include "systemOptions.moc"
